==> org.opennms.features.activemq.pool-19.0.0-20200506.185040-61-sources.jar: org/opennms/features/activemq/PooledConnectionFactory.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2016-2016 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2016 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.activemq;

import javax.jms.Connection;

import org.opennms.core.logging.Logging;

/**
 * Used to create connection pools using our own ConnectionPool subclass.
 * See {@link org.opennms.features.activemq.ConnectionPool} for details.
 *
 * @author jwhite
 */
public class PooledConnectionFactory extends org.apache.activemq.pool.PooledConnectionFactory {

    @Override
    protected ConnectionPool createConnectionPool(Connection connection) {
        // The threads that request and use connections from this pool
        // are related to the IPC modules, so we set the prefix accordingly
        Logging.putPrefix("ipc");
        return new ConnectionPool(connection);
    }

}

==> org.opennms.features.activemq.pool-22.0.0-20171027.120103-10-sources.jar: org/opennms/features/activemq/PooledConnectionFactory.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2016-2016 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2016 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.activemq;

import javax.jms.Connection;

import org.apache.activemq.jms.pool.ConnectionPool;
import org.opennms.core.logging.Logging;

/**
 * Used to create connection pools using our own ConnectionPool subclass.
 * See {@link org.opennms.features.activemq.ConnectionPool} for details.
 *
 * @author jwhite
 */
public class PooledConnectionFactory extends org.apache.activemq.pool.PooledConnectionFactory {

    @Override
    protected ConnectionPool createConnectionPool(Connection connection) {
        // The threads that request and use connections from this pool
        // are related to the IPC modules, so we set the prefix accordingly
        Logging.putPrefix("ipc");
        return super.createConnectionPool(connection);
    }

}
